emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] master b09a6dd 05/29: Rename the package into `math-symbol-lists`


From: Vitalie Spinu
Subject: [elpa] master b09a6dd 05/29: Rename the package into `math-symbol-lists`
Date: Tue, 7 May 2019 13:18:00 -0400 (EDT)

branch: master
commit b09a6dd9d906cb499046718b76292cf1aeb137a4
Author: Vitalie Spinu <address@hidden>
Commit: Vitalie Spinu <address@hidden>

    Rename the package into `math-symbol-lists`
---
 symbols.el => math-symbol-lists.el | 14 +++++++-------
 readme.md                          |  3 ++-
 2 files changed, 9 insertions(+), 8 deletions(-)

diff --git a/readme.md b/readme.md
index 42668f2..ca45e5f 100644
--- a/readme.md
+++ b/readme.md
@@ -1,3 +1,4 @@
 This is a "storage" package used by completion engines such as 
`company-math.el` and `ac-math.el`.
 
-Defined (a)lists are: `symbols-math-basic`, `symbols-math-extended`, 
`symbols-latex-commands`.
+Defined (a)lists are: `math-symbol-list-basic`, `math-symbol-list-extended`,
+`math-symbol-list-latex-commands`.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/symbols.el b/math-symbol-lists.el
similarity index 99%
rename from symbols.el
rename to math-symbol-lists.el
index 168af1c..bbf98ea 100644
--- a/symbols.el
+++ b/math-symbol-lists.el
@@ -1,9 +1,9 @@
 ;;; symbols.el --- Lists of Unicode mathematical symbols and latex commands
commands
 ;;
 ;; Copyright (C) 2014, Vitalie Spinu
 ;; Author: Vitalie Spinu
-;; URL: https://github.com/vspinu/symbols.el
-;; Keywords: Unicode, symbols
+;; URL: https://github.com/vspinu/math-symbol-lists
+;; Keywords: Unicode, symbols, mathematics
 ;; Version: 1.0
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -43,7 +43,7 @@
 ;;; Code:
 
 ;;;###autoload
-(defconst symbols-math-basic
+(defconst math-symbol-list-basic
   '(("Greek Lowercase" "\\alpha"       #X3B1)
     ("Greek Lowercase" "\\beta"        #X3B2)
     ("Greek Lowercase" "\\gamma"       #X3B3)
@@ -564,7 +564,7 @@
   "List of basic mathematical symbols.")
 
 ;;;###autoload
-(defconst symbols-math-extended
+(defconst math-symbol-list-extended
   '(("punct"   "\\exclam"      #X21)
     ("ord"     "\\octothorpe"  #X23)
     ("ord"     "\\mathdollar"  #X24)
@@ -3006,7 +3006,7 @@
   "Extended list of mathematical symbols")
 
 ;;;###autoload
-(defconst symbols-latex-commands
+(defconst math-symbol-list-latex-commands
   '("address" "addtocounter" "addtolength" "addvspace" "Alph" "alph" "Alph
     example" "alsoname" "and for author" "appendix" "arabic" "arraycolsep"
     "arrayrulewidth" "arraystretch" "baselineskip"
@@ -3065,4 +3065,4 @@
     "width" "year")
   "List of the latex commands.")
 
-(provide 'symbols)
+(provide 'math-symbol-lists)
@@ -1,9 +1,9 @@
-;;; symbols.el --- Lists of Unicode mathematical symbols and latex commands
+;;; math-symbol-lists.el --- Lists of Unicode mathematical symbols and latex 
commands
 ;;